You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cloudstack.apache.org by je...@apache.org on 2014/11/04 20:35:58 UTC

git commit: updated refs/heads/master to 4d62dbb

Repository: cloudstack
Updated Branches:
  refs/heads/master 0327c2b13 -> 4d62dbb8b


CLOUDSTACK-7384: UI > Instances > detailView > change service offering option > hide it when VM state is Running and hyperviror is LXC.


Project: http://git-wip-us.apache.org/repos/asf/cloudstack/repo
Commit: http://git-wip-us.apache.org/repos/asf/cloudstack/commit/4d62dbb8
Tree: http://git-wip-us.apache.org/repos/asf/cloudstack/tree/4d62dbb8
Diff: http://git-wip-us.apache.org/repos/asf/cloudstack/diff/4d62dbb8

Branch: refs/heads/master
Commit: 4d62dbb8ba3e3d987a92d8c872302901bc23e0bc
Parents: 0327c2b
Author: Jessica Wang <je...@apache.org>
Authored: Tue Nov 4 11:33:15 2014 -0800
Committer: Jessica Wang <je...@apache.org>
Committed: Tue Nov 4 11:35:43 2014 -0800

----------------------------------------------------------------------
 ui/scripts/instances.js | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cloudstack/blob/4d62dbb8/ui/scripts/instances.js
----------------------------------------------------------------------
diff --git a/ui/scripts/instances.js b/ui/scripts/instances.js
index 838e4d5..3cf5dd6 100644
--- a/ui/scripts/instances.js
+++ b/ui/scripts/instances.js
@@ -2253,8 +2253,8 @@
             allowedActions.push("destroy");            
             allowedActions.push("reinstall");
              
-            //when userVm is running, scaleUp is not supported for KVM
-            if (jsonObj.hypervisor != 'KVM') {
+            //when userVm is running, scaleUp is not supported for KVM, LXC
+            if (jsonObj.hypervisor != 'KVM' && jsonObj.hypervisor != 'LXC') {
             	allowedActions.push("scaleUp");
             }